@@ -60,88 +60,6 @@ class Interferometer(abstract_dataset.AbstractDataset):
 
         Parameters
         ----------
-        lens_name
-        image_path : str
-            The path to the image .fits file containing the image (e.g. '/path/to/image.fits')
-        image_hdu : int
-            The hdu the image is contained in the .fits file specified by *image_path*.
-        image_hdu : int
-            The hdu the image is contained in the .fits file that *image_path* points too.
-        resized_interferometer_shape : (int, int) | None
-            If input, the interferometer structures that are image sized, e.g. the image, noise-maps) are resized to these dimensions.
-        resized_interferometer_origin_pixels : (int, int) | None
-            If the interferometer structures are resized, this defines a new origin (in pixels) around which recentering occurs.
-        resized_interferometer_origin_arcsec : (float, float) | None
-            If the interferometer structures are resized, this defines a new origin (in arc-seconds) around which recentering occurs.
-        primary_beam_path : str
-            The path to the primary_beam .fits file containing the primary_beam (e.g. '/path/to/primary_beam.fits')
-        primary_beam_hdu : int
-            The hdu the primary_beam is contained in the .fits file specified by *primary_beam_path*.
-        resized_primary_beam_shape_2d : (int, int) | None
-            If input, the primary_beam is resized to these dimensions.
-        renormalize_psf : bool
-            If True, the PrimaryBeam is renoralized such that all elements sum to 1.0.
-        noise_map_path : str
-            The path to the noise_map .fits file containing the noise_map (e.g. '/path/to/noise_map.fits')
-        noise_map_hdu : int
-            The hdu the noise_map is contained in the .fits file specified by *noise_map_path*.
-        noise_map_from_image_and_background_noise_map : bool
-            If True, the noise-map is computed from the observed image and background noise-map \
-            (see NoiseMap.from_image_and_background_noise_map).
-        convert_noise_map_from_weight_map : bool
-            If True, the noise-map loaded from the .fits file is converted from a weight-map to a noise-map (see \
-            *NoiseMap.from_weight_map).
-        convert_noise_map_from_inverse_noise_map : bool
-            If True, the noise-map loaded from the .fits file is converted from an inverse noise-map to a noise-map (see \
-            *NoiseMap.from_inverse_noise_map).
-        background_noise_map_path : str
-            The path to the background_noise_map .fits file containing the background noise-map \
-            (e.g. '/path/to/background_noise_map.fits')
-        background_noise_map_hdu : int
-            The hdu the background_noise_map is contained in the .fits file specified by *background_noise_map_path*.
-        convert_background_noise_map_from_weight_map : bool
-            If True, the bacground noise-map loaded from the .fits file is converted from a weight-map to a noise-map (see \
-            *NoiseMap.from_weight_map).
-        convert_background_noise_map_from_inverse_noise_map : bool
-            If True, the background noise-map loaded from the .fits file is converted from an inverse noise-map to a \
-            noise-map (see *NoiseMap.from_inverse_noise_map).
-        poisson_noise_map_path : str
-            The path to the poisson_noise_map .fits file containing the Poisson noise-map \
-             (e.g. '/path/to/poisson_noise_map.fits')
-        poisson_noise_map_hdu : int
-            The hdu the poisson_noise_map is contained in the .fits file specified by *poisson_noise_map_path*.
-        poisson_noise_map_from_image : bool
-            If True, the Poisson noise-map is estimated using the image.
-        convert_poisson_noise_map_from_weight_map : bool
-            If True, the Poisson noise-map loaded from the .fits file is converted from a weight-map to a noise-map (see \
-            *NoiseMap.from_weight_map).
-        convert_poisson_noise_map_from_inverse_noise_map : bool
-            If True, the Poisson noise-map loaded from the .fits file is converted from an inverse noise-map to a \
-            noise-map (see *NoiseMap.from_inverse_noise_map).
-        exposure_time_map_path : str
-            The path to the exposure_time_map .fits file containing the exposure time map \
-            (e.g. '/path/to/exposure_time_map.fits')
-        exposure_time_map_hdu : int
-            The hdu the exposure_time_map is contained in the .fits file specified by *exposure_time_map_path*.
-        exposure_time_map_from_single_value : float
-            The exposure time of the interferometer imaging, which is used to compute the exposure-time map as a single value \
-            (see *ExposureTimeMap.from_single_value*).
-        exposure_time_map_from_inverse_noise_map : bool
-            If True, the exposure-time map is computed from the background noise-map \
-            (see *ExposureTimeMap.from_background_noise_map*)
-        background_sky_map_path : str
-            The path to the background_sky_map .fits file containing the background sky map \
-            (e.g. '/path/to/background_sky_map.fits').
-        background_sky_map_hdu : int
-            The hdu the background_sky_map is contained in the .fits file specified by *background_sky_map_path*.
-        convert_from_electrons : bool
-            If True, the input unblurred_image_1d are in units of electrons and all converted to electrons / second using the exposure \
-            time map.
-        gain : float
-            The image gain, used for convert from ADUs.
-        convert_from_adus : bool
-            If True, the input unblurred_image_1d are in units of adus and all converted to electrons / second using the exposure \
-            time map and gain.
         """
 
         visibilities = aa.Visibilities.from_fits(
@@ -311,6 +229,10 @@ class MaskedInterferometer(abstract_dataset.AbstractMaskedDataset):
         self.noise_map = interferometer.noise_map
         self.visibilities_mask = visibilities_mask
 
+    @property
+    def dataset(self):
+        return self.interferometer
+
     @property
     def data(self):
         return self.visibilities
