@@ -1,5 +1,7 @@
 from autoarray import decorator_util
 import numpy as np
+from astropy.io import fits
+import os
 
 
 @decorator_util.jit()
@@ -150,7 +152,6 @@ def data_vector_from_transformed_mapping_matrix_and_data(
     return data_vector
 
 
-@decorator_util.jit()
 def curvature_matrix_from_transformed_mapping_matrix(
     transformed_mapping_matrix, noise_map
 ):
@@ -168,22 +169,9 @@ def curvature_matrix_from_transformed_mapping_matrix(
     iflist : ndarray
         NumPy array of integers used to store mappings for efficienctly calculation.
     """
-    curvature_matrix = np.zeros(
-        (transformed_mapping_matrix.shape[1], transformed_mapping_matrix.shape[1])
-    )
 
-    for pix_1d_index_0 in range(transformed_mapping_matrix.shape[1]):
-        for pix_1d_index_1 in range(pix_1d_index_0 + 1):
-            for vis_1d_index in range(transformed_mapping_matrix.shape[0]):
-                curvature_matrix[pix_1d_index_0, pix_1d_index_1] += (
-                    transformed_mapping_matrix[vis_1d_index, pix_1d_index_0]
-                    * transformed_mapping_matrix[vis_1d_index, pix_1d_index_1]
-                    / noise_map[vis_1d_index] ** 2
-                )
-
-    for i in range(transformed_mapping_matrix.shape[1]):
-        for j in range(transformed_mapping_matrix.shape[1]):
-            curvature_matrix[i, j] = curvature_matrix[j, i]
+    array = transformed_mapping_matrix / noise_map[:, None]
+    curvature_matrix = np.dot(array.T, np.matrix.transpose(array.T))
 
     return curvature_matrix
 
@@ -202,6 +190,7 @@ def inversion_residual_map_from_pixelization_values_and_data(
     for pix_1_index, sub_mask_1d_indexes in enumerate(
         all_sub_mask_1d_indexes_for_pixelization_1d_index
     ):
+
         sub_mask_total = 0
         for sub_mask_1d_index in sub_mask_1d_indexes:
             sub_mask_total += 1
@@ -212,12 +201,12 @@ def inversion_residual_map_from_pixelization_values_and_data(
         if sub_mask_total > 0:
             residual_map[pix_1_index] /= sub_mask_total
 
-    return residual_map
+    return residual_map.copy()
 
 
 def inversion_normalized_residual_map_from_pixelization_values_and_reconstructed_data_1d(
     pixelization_values,
-    mapped_reconstructed_data,
+    data,
     noise_map_1d,
     mask_1d_index_for_sub_mask_1d_index,
     all_sub_mask_1d_indexes_for_pixelization_1d_index,
@@ -227,8 +216,6 @@ def inversion_normalized_residual_map_from_pixelization_values_and_reconstructed
         shape=len(all_sub_mask_1d_indexes_for_pixelization_1d_index)
     )
 
-    mapped_reconstructed_data = mapped_reconstructed_data
-
     for pix_1_index, sub_mask_1d_indexes in enumerate(
         all_sub_mask_1d_indexes_for_pixelization_1d_index
     ):
@@ -236,10 +223,7 @@ def inversion_normalized_residual_map_from_pixelization_values_and_reconstructed
         for sub_mask_1d_index in sub_mask_1d_indexes:
             sub_mask_total += 1
             mask_1d_index = mask_1d_index_for_sub_mask_1d_index[sub_mask_1d_index]
-            residual = (
-                mapped_reconstructed_data[mask_1d_index]
-                - pixelization_values[pix_1_index]
-            )
+            residual = data[mask_1d_index] - pixelization_values[pix_1_index]
             normalized_residual_map[pix_1_index] += np.abs(
                 (residual / noise_map_1d[mask_1d_index])
             )
@@ -247,12 +231,12 @@ def inversion_normalized_residual_map_from_pixelization_values_and_reconstructed
         if sub_mask_total > 0:
             normalized_residual_map[pix_1_index] /= sub_mask_total
 
-    return normalized_residual_map
+    return normalized_residual_map.copy()
 
 
 def inversion_chi_squared_map_from_pixelization_values_and_reconstructed_data_1d(
     pixelization_values,
-    mapped_reconstructed_data,
+    data,
     noise_map_1d,
     mask_1d_index_for_sub_mask_1d_index,
     all_sub_mask_1d_indexes_for_pixelization_1d_index,
@@ -269,10 +253,7 @@ def inversion_chi_squared_map_from_pixelization_values_and_reconstructed_data_1d
         for sub_mask_1d_index in sub_mask_1d_indexes:
             sub_mask_total += 1
             mask_1d_index = mask_1d_index_for_sub_mask_1d_index[sub_mask_1d_index]
-            residual = (
-                mapped_reconstructed_data[mask_1d_index]
-                - pixelization_values[pix_1_index]
-            )
+            residual = data[mask_1d_index] - pixelization_values[pix_1_index]
             chi_squared_map[pix_1_index] += (
                 residual / noise_map_1d[mask_1d_index]
             ) ** 2.0
@@ -280,4 +261,4 @@ def inversion_chi_squared_map_from_pixelization_values_and_reconstructed_data_1d
         if sub_mask_total > 0:
             chi_squared_map[pix_1_index] /= sub_mask_total
 
-    return chi_squared_map
+    return chi_squared_map.copy()
