@@ -7,9 +7,7 @@ import numpy as np
 import pytest
 
 
-test_data_path = "{}/../test_files/array/".format(
-    os.path.dirname(os.path.realpath(__file__))
-)
+test_data_path = "{}/files/array/".format(os.path.dirname(os.path.realpath(__file__)))
 
 
 @pytest.fixture(name="memoizer")
@@ -396,17 +394,17 @@ class TestFits:
 
     def test__numpy_array_1d_to_fits__output_and_load(self):
 
-        if os.path.exists(test_data_path + "test_autoarray.fits"):
-            os.remove(test_data_path + "test_autoarray.fits")
+        if os.path.exists(test_data_path + "array_out.fits"):
+            os.remove(test_data_path + "array_out.fits")
 
         arr = np.array([10.0, 30.0, 40.0, 92.0, 19.0, 20.0])
 
         util.array.numpy_array_1d_to_fits(
-            arr, file_path=test_data_path + "test_autoarray.fits"
+            arr, file_path=test_data_path + "array_out.fits"
         )
 
         array_load = util.array.numpy_array_1d_from_fits(
-            file_path=test_data_path + "test_autoarray.fits", hdu=0
+            file_path=test_data_path + "array_out.fits", hdu=0
         )
 
         assert (arr == array_load).all()
@@ -426,17 +424,17 @@ class TestFits:
 
     def test__numpy_array_2d_to_fits__output_and_load(self):
 
-        if os.path.exists(test_data_path + "test_autoarray.fits"):
-            os.remove(test_data_path + "test_autoarray.fits")
+        if os.path.exists(test_data_path + "array_out.fits"):
+            os.remove(test_data_path + "array_out.fits")
 
         arr = np.array([[10.0, 30.0, 40.0], [92.0, 19.0, 20.0]])
 
         util.array.numpy_array_2d_to_fits(
-            arr, file_path=test_data_path + "test_autoarray.fits"
+            arr, file_path=test_data_path + "array_out.fits"
         )
 
         array_load = util.array.numpy_array_2d_from_fits(
-            file_path=test_data_path + "test_autoarray.fits", hdu=0
+            file_path=test_data_path + "array_out.fits", hdu=0
         )
 
         assert (arr == array_load).all()
