@@ -4,17 +4,12 @@ import os
 import numpy as np
 
 
-test_data_dir = "{}/../test_files/array/".format(
-    os.path.dirname(os.path.realpath(__file__))
-)
-
-
 class TestUnmaskedSparseForSparse:
     def test__mask_full_false__image_mask_and_pixel_centres_fully_overlap__each_sparse_maps_to_unmaked_sparse(
         self
     ):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [[False, False, False], [False, False, False], [False, False, False]]
             ),
@@ -45,7 +40,7 @@ class TestUnmaskedSparseForSparse:
         self
     ):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [[False, False, False], [False, False, False], [False, False, False]]
             ),
@@ -72,7 +67,7 @@ class TestUnmaskedSparseForSparse:
 
     def test__mask_is_cross__some_pix_pixels_are_masked__omitted_from_mapping(self):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [[True, False, True], [False, False, False], [True, False, True]]
             ),
@@ -99,7 +94,7 @@ class TestUnmaskedSparseForSparse:
 
     def test__same_as_above__different_mask_and_centres(self):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [[False, False, True], [False, False, False], [True, False, False]]
             ),
@@ -126,7 +121,7 @@ class TestUnmaskedSparseForSparse:
 
     def test__same_as_above__but_3x4_mask(self):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [
                     [True, True, False, True],
@@ -157,7 +152,7 @@ class TestUnmaskedSparseForSparse:
 
     def test__same_as_above__but_4x3_mask(self):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [
                     [True, False, True],
@@ -193,7 +188,7 @@ class TestSparseForUnmaskedSparse:
         self
     ):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [[False, False, False], [False, False, False], [False, False, False]]
             ),
@@ -219,7 +214,7 @@ class TestSparseForUnmaskedSparse:
         self
     ):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [[False, False, False], [False, False, False], [False, False, False]]
             ),
@@ -241,7 +236,7 @@ class TestSparseForUnmaskedSparse:
 
     def test__mask_is_cross__some_pix_pixels_are_masked__omitted_from_mapping(self):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [[True, False, True], [False, False, False], [True, False, True]]
             ),
@@ -265,7 +260,7 @@ class TestSparseForUnmaskedSparse:
 
     def test__same_as_above__different_mask_and_centres(self):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [[False, False, True], [False, False, False], [True, False, False]]
             ),
@@ -287,7 +282,7 @@ class TestSparseForUnmaskedSparse:
 
     def test__same_as_above__but_3x4_mask(self):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [
                     [True, True, False, True],
@@ -313,7 +308,7 @@ class TestSparseForUnmaskedSparse:
 
     def test__same_as_above__but_4x3_mask(self):
 
-        ma = aa.mask.manual(
+        ma = aa.Mask.manual(
             mask_2d=np.array(
                 [
                     [True, False, True],
